==> ui-framework-4.14.2-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractLayerExamplesMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractLayerExamplesMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _7_1_01287379502 _7_1_01287379502;
	public LayerExamplesMold._7_1_01287379502. _8_2_0725774549 _8_2_0725774549;
	public LayerExamplesMold._7_1_01287379502._8_2_0725774549. _9_3_0308355687 _9_3_0308355687;
	public LayerExamplesMold._7_1_01287379502._8_2_0725774549. _10_3_11347249721 _10_3_11347249721;
	public LayerExamplesMold._7_1_01287379502._8_2_0725774549._10_3_11347249721. OpenLayerTrigger openLayerTrigger;
	public LayerExamplesMold._7_1_01287379502._8_2_0725774549. _12_3_0712131888 _12_3_0712131888;
	public LayerExamplesMold._7_1_01287379502._8_2_0725774549._12_3_0712131888. _12_11_11007714113 _12_11_11007714113;

    public AbstractLayerExamplesMold(B box) {
        super(box);
        id("layerExamplesMold");
    }

    @Override
	public void init() {
		super.init();
		if (_7_1_01287379502 == null) _7_1_01287379502 = register(new _7_1_01287379502(box()).<_7_1_01287379502>id("a203912007").owner(AbstractLayerExamplesMold.this));
		if (_7_1_01287379502 != null) _8_2_0725774549 = _7_1_01287379502._8_2_0725774549;
		if (_8_2_0725774549 != null) _9_3_0308355687 = _7_1_01287379502._8_2_0725774549._9_3_0308355687;
		if (_8_2_0725774549 != null) _10_3_11347249721 = _7_1_01287379502._8_2_0725774549._10_3_11347249721;
		if (_10_3_11347249721 != null) openLayerTrigger = _7_1_01287379502._8_2_0725774549._10_3_11347249721.openLayerTrigger;
		if (_8_2_0725774549 != null) _12_3_0712131888 = _7_1_01287379502._8_2_0725774549._12_3_0712131888;
		if (_12_3_0712131888 != null) _12_11_11007714113 = _7_1_01287379502._8_2_0725774549._12_3_0712131888._12_11_11007714113;
	}

	public class _7_1_01287379502 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public LayerExamplesMold._7_1_01287379502. _8_2_0725774549 _8_2_0725774549;

		public _7_1_01287379502(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_8_2_0725774549 == null) _8_2_0725774549 = register(new _8_2_0725774549(box()).<_8_2_0725774549>id("a65626495").owner(AbstractLayerExamplesMold.this));
		}

		public class _8_2_0725774549 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public LayerExamplesMold._7_1_01287379502._8_2_0725774549. _9_3_0308355687 _9_3_0308355687;
			public LayerExamplesMold._7_1_01287379502._8_2_0725774549. _10_3_11347249721 _10_3_11347249721;
			public LayerExamplesMold._7_1_01287379502._8_2_0725774549. _12_3_0712131888 _12_3_0712131888;

			public _8_2_0725774549(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_9_3_0308355687 == null) _9_3_0308355687 = register(new _9_3_0308355687(box()).<_9_3_0308355687>id("a_2101570724").owner(AbstractLayerExamplesMold.this));
				if (_10_3_11347249721 == null) _10_3_11347249721 = register(new _10_3_11347249721(box()).<_10_3_11347249721>id("a685893318").owner(AbstractLayerExamplesMold.this));
				if (_12_3_0712131888 == null) _12_3_0712131888 = register(new _12_3_0712131888(box()).<_12_3_0712131888>id("a1912209854").owner(AbstractLayerExamplesMold.this));
			}

			public class _9_3_0308355687 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _9_3_0308355687(B box) {
					super(box);
					_value("No facets");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class _10_3_11347249721 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public LayerExamplesMold._7_1_01287379502._8_2_0725774549._10_3_11347249721. OpenLayerTrigger openLayerTrigger;

				public _10_3_11347249721(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (openLayerTrigger == null) openLayerTrigger = register(new OpenLayerTrigger(box()).<OpenLayerTrigger>id("a_1661163857").owner(AbstractLayerExamplesMold.this));
				}

				public class OpenLayerTrigger extends io.intino.alexandria.ui.displays.components.OpenLayer<io.intino.alexandria.ui.displays.notifiers.OpenLayerNotifier, B>  {

					public OpenLayerTrigger(B box) {
						super(box);
						_title("open layer");
						_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Button"));
					}

					@Override
					public void init() {
						super.init();
					}
				}
			}

			public class _12_3_0712131888 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public LayerExamplesMold._7_1_01287379502._8_2_0725774549._12_3_0712131888. _12_11_11007714113 _12_11_11007714113;

				public _12_3_0712131888(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_12_11_11007714113 == null) _12_11_11007714113 = register(new _12_11_11007714113(box()).<_12_11_11007714113>id("a585835436").owner(AbstractLayerExamplesMold.this));
				}

				public class _12_11_11007714113 extends io.intino.alexandria.ui.displays.components.TextCode<io.intino.alexandria.ui.displays.notifiers.TextCodeNotifier, B>  {

					public _12_11_11007714113(B box) {
						super(box);
						_value("Button(title=\"open layer\") as OpenLayer");
					}

					@Override
					public void init() {
						super.init();
					}
				}
			}
		}
	}
}

==> ui-framework-4.17.6-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractLayerExamplesMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractLayerExamplesMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _7_1_01287379502 _7_1_01287379502;
	public LayerExamplesMold._7_1_01287379502. _8_2_0725774549 _8_2_0725774549;
	public LayerExamplesMold._7_1_01287379502._8_2_0725774549. _9_3_0308355687 _9_3_0308355687;
	public LayerExamplesMold._7_1_01287379502._8_2_0725774549. _10_3_11347249721 _10_3_11347249721;
	public LayerExamplesMold._7_1_01287379502._8_2_0725774549._10_3_11347249721. OpenLayerTrigger openLayerTrigger;
	public LayerExamplesMold._7_1_01287379502._8_2_0725774549. _12_3_0712131888 _12_3_0712131888;
	public LayerExamplesMold._7_1_01287379502._8_2_0725774549._12_3_0712131888. _12_11_11007714113 _12_11_11007714113;

    public AbstractLayerExamplesMold(B box) {
        super(box);
        id("layerExamplesMold");
    }

    @Override
	public void init() {
		super.init();
		if (_7_1_01287379502 == null) _7_1_01287379502 = register(new _7_1_01287379502(box()).<_7_1_01287379502>id("a203912007").owner(AbstractLayerExamplesMold.this));
		if (_7_1_01287379502 != null) _8_2_0725774549 = _7_1_01287379502._8_2_0725774549;
		if (_8_2_0725774549 != null) _9_3_0308355687 = _7_1_01287379502._8_2_0725774549._9_3_0308355687;
		if (_8_2_0725774549 != null) _10_3_11347249721 = _7_1_01287379502._8_2_0725774549._10_3_11347249721;
		if (_10_3_11347249721 != null) openLayerTrigger = _7_1_01287379502._8_2_0725774549._10_3_11347249721.openLayerTrigger;
		if (_8_2_0725774549 != null) _12_3_0712131888 = _7_1_01287379502._8_2_0725774549._12_3_0712131888;
		if (_12_3_0712131888 != null) _12_11_11007714113 = _7_1_01287379502._8_2_0725774549._12_3_0712131888._12_11_11007714113;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_7_1_01287379502 != null) _7_1_01287379502.unregister();
	}

	public class _7_1_01287379502 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public LayerExamplesMold._7_1_01287379502. _8_2_0725774549 _8_2_0725774549;

		public _7_1_01287379502(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_8_2_0725774549 == null) _8_2_0725774549 = register(new _8_2_0725774549(box()).<_8_2_0725774549>id("a65626495").owner(AbstractLayerExamplesMold.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_8_2_0725774549 != null) _8_2_0725774549.unregister();
		}

		public class _8_2_0725774549 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public LayerExamplesMold._7_1_01287379502._8_2_0725774549. _9_3_0308355687 _9_3_0308355687;
			public LayerExamplesMold._7_1_01287379502._8_2_0725774549. _10_3_11347249721 _10_3_11347249721;
			public LayerExamplesMold._7_1_01287379502._8_2_0725774549. _12_3_0712131888 _12_3_0712131888;

			public _8_2_0725774549(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_9_3_0308355687 == null) _9_3_0308355687 = register(new _9_3_0308355687(box()).<_9_3_0308355687>id("a_2101570724").owner(AbstractLayerExamplesMold.this));
				if (_10_3_11347249721 == null) _10_3_11347249721 = register(new _10_3_11347249721(box()).<_10_3_11347249721>id("a685893318").owner(AbstractLayerExamplesMold.this));
				if (_12_3_0712131888 == null) _12_3_0712131888 = register(new _12_3_0712131888(box()).<_12_3_0712131888>id("a1912209854").owner(AbstractLayerExamplesMold.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_9_3_0308355687 != null) _9_3_0308355687.unregister();
				if (_10_3_11347249721 != null) _10_3_11347249721.unregister();
				if (_12_3_0712131888 != null) _12_3_0712131888.unregister();
			}

			public class _9_3_0308355687 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _9_3_0308355687(B box) {
					super(box);
					_value("No facets");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}

			public class _10_3_11347249721 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public LayerExamplesMold._7_1_01287379502._8_2_0725774549._10_3_11347249721. OpenLayerTrigger openLayerTrigger;

				public _10_3_11347249721(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (openLayerTrigger == null) openLayerTrigger = register(new OpenLayerTrigger(box()).<OpenLayerTrigger>id("a_1661163857").owner(AbstractLayerExamplesMold.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (openLayerTrigger != null) openLayerTrigger.unregister();
				}

				public class OpenLayerTrigger extends io.intino.alexandria.ui.displays.components.OpenLayer<io.intino.alexandria.ui.displays.notifiers.OpenLayerNotifier, B>  {

					public OpenLayerTrigger(B box) {
						super(box);
						_title("open layer");
						_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Button"));

						_transition(io.intino.alexandria.ui.displays.components.OpenLayer.Transition.valueOf("Slide"));
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}
			}

			public class _12_3_0712131888 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public LayerExamplesMold._7_1_01287379502._8_2_0725774549._12_3_0712131888. _12_11_11007714113 _12_11_11007714113;

				public _12_3_0712131888(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (_12_11_11007714113 == null) _12_11_11007714113 = register(new _12_11_11007714113(box()).<_12_11_11007714113>id("a585835436").owner(AbstractLayerExamplesMold.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (_12_11_11007714113 != null) _12_11_11007714113.unregister();
				}

				public class _12_11_11007714113 extends io.intino.alexandria.ui.displays.components.TextCode<io.intino.alexandria.ui.displays.notifiers.TextCodeNotifier, B>  {

					public _12_11_11007714113(B box) {
						super(box);
						_value("Button(title=\"open layer\") as OpenLayer");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}
			}
		}
	}
}
